@@ -51,6 +51,7 @@
 
 #include <KActionCollection>
 #include <KActionMenu>
+#include <KColorSchemeMenu>
 #include <KMessageBox>
 #include <KSelectAction>
 #include <KShortcutsDialog>
@@ -187,7 +188,7 @@ void ActionManager::createCalendarAkonadi()
     Q_ASSERT(calendar());
 
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    mCollectionSelectionModelStateSaver = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(config->group("GlobalCollectionSelection"));
+    mCollectionSelectionModelStateSaver = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(config->group(QStringLiteral("GlobalCollectionSelection")));
     mCollectionSelectionModelStateSaver->setSelectionModel(calendar()->checkableProxyModel()->selectionModel());
 
     AkonadiCollectionViewFactory factory(mCalendarView);
@@ -200,7 +201,7 @@ void ActionManager::createCalendarAkonadi()
 
     connect(mCollectionView, &AkonadiCollectionView::colorsChanged, mCalendarView, qOverload<>(&CalendarView::updateConfig));
 
-    mCollectionViewStateSaver = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(config->group("GlobalCollectionView"));
+    mCollectionViewStateSaver = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(config->group(QStringLiteral("GlobalCollectionView")));
     mCollectionViewStateSaver->setView(mCollectionView->view());
 
     KCheckableProxyModel *checkableProxy = calendar()->checkableProxyModel();
@@ -213,7 +214,7 @@ void ActionManager::createCalendarAkonadi()
 
     mCalendarView->readSettings();
 
-    connect(calendar().data(), &Akonadi::ETMCalendar::calendarChanged, mCalendarView, &CalendarView::resourcesChanged);
+    // connect(calendar().data(), &Akonadi::ETMCalendar::calendarChanged, mCalendarView, &CalendarView::resourcesChanged);
     connect(mCalendarView, &CalendarView::configChanged, this, &ActionManager::updateConfig);
 
     calendar()->setOwner(KCalendarCore::Person(CalendarSupport::KCalPrefs::instance()->fullName(), CalendarSupport::KCalPrefs::instance()->email()));
@@ -720,7 +721,7 @@ void ActionManager::initActions()
     mACollection->addAction(QStringLiteral("show_eventviewer"), mEventViewerShowAction);
     connect(mEventViewerShowAction, &KToggleAction::triggered, this, &ActionManager::toggleEventViewer);
 
-    KConfigGroup config(KSharedConfig::openConfig(), "Settings");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("Settings"));
     mDateNavigatorShowAction->setChecked(config.readEntry("DateNavigatorVisible", true));
     // if we are a kpart, then let's not show the todo in the left pane by
     // default since there's also a Todo part and we'll assume they'll be
@@ -758,7 +759,7 @@ void ActionManager::initActions()
     connect(action, &QAction::triggered, mCalendarView->dialogManager(), &KODialogManager::showCategoryEditDialog);
 
     auto manager = new KColorSchemeManager(this);
-    mACollection->addAction(QStringLiteral("colorscheme_menu"), manager->createSchemeSelectionMenu(this));
+    mACollection->addAction(QStringLiteral("colorscheme_menu"), KColorSchemeMenu::createMenu(manager, this));
 
     if (mIsPart) {
         action = new QAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("&Configure KOrganizer..."), this);
@@ -789,9 +790,9 @@ void ActionManager::updateHamburgerMenu()
 
     menu->addAction(mACollection->action(QStringLiteral("conf_datetime")));
     menu->addSeparator();
-    menu->addAction(mACollection->action(QLatin1String(KStandardAction::name(KStandardAction::Print))));
+    menu->addAction(mACollection->action(KStandardAction::name(KStandardAction::Print)));
     menu->addSeparator();
-    menu->addAction(mACollection->action(QLatin1String(KStandardAction::name(KStandardAction::Quit))));
+    menu->addAction(mACollection->action(KStandardAction::name(KStandardAction::Quit)));
     mHamburgerMenu->setMenu(menu);
 }
 
@@ -877,7 +878,7 @@ void ActionManager::restoreCollectionViewSetting()
 void ActionManager::writeSettings()
 {
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup group = config->group("Settings");
+    KConfigGroup group = config->group(QStringLiteral("Settings"));
     mCalendarView->writeSettings();
 
     if (mDateNavigatorShowAction) {
@@ -899,8 +900,8 @@ void ActionManager::writeSettings()
     mCollectionViewStateSaver->saveState();
     mCollectionSelectionModelStateSaver->saveState();
 
-    KConfigGroup selectionViewGroup = config->group("GlobalCollectionView");
-    KConfigGroup selectionGroup = config->group("GlobalCollectionSelection");
+    KConfigGroup selectionViewGroup = config->group(QStringLiteral("GlobalCollectionView"));
+    KConfigGroup selectionGroup = config->group(QStringLiteral("GlobalCollectionSelection"));
     selectionGroup.sync();
     selectionViewGroup.sync();
     config->sync();
@@ -1032,7 +1033,7 @@ bool ActionManager::saveAsURL(const QUrl &url)
         mTempFile = tempFile;
         setTitle();
     } else {
-        KMessageBox::error(dialogParent(), i18n("Unable to save calendar to the file %1.", mFile), i18n("Error"));
+        KMessageBox::error(dialogParent(), i18n("Unable to save calendar to the file %1.", mFile), i18nc("@title:window", "Error"));
         qCDebug(KORGANIZER_LOG) << "failed";
         mURL = URLOrig;
         mFile = fileOrig;
@@ -1072,11 +1073,7 @@ void ActionManager::updateConfig()
 void ActionManager::configureDateTime()
 {
     QProcess proc;
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    const QString program = QStringLiteral("kcmshell5");
-#else
     const QString program = QStringLiteral("kcmshell6");
-#endif
     QStringList arguments;
     arguments << QStringLiteral("formats") << QStringLiteral("translations") << QStringLiteral("clock");
 
@@ -1177,7 +1174,7 @@ bool ActionManager::showIncidenceContext(Akonadi::Item::Id id)
 
 void ActionManager::showIncidenceByUid(const QString &uid, const QDateTime &occurrence, const QString &xdgActivationToken)
 {
-    mCalendarView->showIncidenceByUid(uid, occurrence.date());
+    mCalendarView->showIncidenceByUid(uid);
     mCalendarView->showDate(occurrence.date());
 
     KWindowSystem::setCurrentXdgActivationToken(xdgActivationToken);
@@ -1320,6 +1317,11 @@ void ActionManager::processIncidenceSelection(const Akonadi::Item &item, QDate d
     // qCDebug(KORGANIZER_LOG) << "ActionManager::processIncidenceSelection()";
     Q_UNUSED(date)
 
+    if (!item.isValid()) {
+        enableIncidenceActions(false);
+        return;
+    }
+
     const KCalendarCore::Incidence::Ptr incidence = Akonadi::CalendarUtils::incidence(item);
     if (!incidence) {
         enableIncidenceActions(false);
@@ -1456,7 +1458,7 @@ void ActionManager::openEventEditor(const QString &summary,
         } else {
             if (KMessageBox::warningContinueCancel(nullptr,
                                                    i18n("Removing attachments from an email might invalidate its signature."),
-                                                   i18n("Remove Attachments"),
+                                                   i18nc("@title:window", "Remove Attachments"),
                                                    KStandardGuiItem::cont(),
                                                    KStandardGuiItem::cancel(),
                                                    QStringLiteral("BodyOnlyInlineAttachment"))
@@ -1726,3 +1728,5 @@ void ActionManager::openEventEditor(const QString &summary,
     Q_UNUSED(attachmentIsInline)
     qCWarning(KORGANIZER_LOG) << "Not implemented in korg-desktop";
 }
+
+#include "moc_actionmanager.cpp"
