@@ -22,11 +22,11 @@ public:
 
     ~KOCoreHelper() override = default;
 
-    Q_REQUIRED_RESULT QColor categoryColor(const QStringList &cats) override;
+    [[nodiscard]] QColor categoryColor(const QStringList &cats) override;
 
-    Q_REQUIRED_RESULT QString holidayString(const QDate &dt) override;
+    [[nodiscard]] QString holidayString(const QDate &dt) override;
 
-    Q_REQUIRED_RESULT QTime dayStart() override
+    [[nodiscard]] QTime dayStart() override
     {
         return KOPrefs::instance()->mDayBegins.time();
     }
