@@ -10,7 +10,7 @@
 
 #pragma once
 
-#include <Akonadi/ETMCalendar>
+#include <Akonadi/CollectionCalendar>
 
 #include <KCalendarCore/IncidenceBase> //for KCalendarCore::DateList typedef
 
@@ -50,7 +50,7 @@
  *
  *  @author Eitzenberger Thomas
  */
-class KODayMatrix : public QFrame, public Akonadi::ETMCalendar::CalendarObserver
+class KODayMatrix : public QFrame, public KCalendarCore::Calendar::CalendarObserver
 {
     Q_OBJECT
 public:
@@ -68,13 +68,14 @@ public:
     /** returns the first and last date of the 6*7 matrix that displays @p month
      * @param month The month we want to get matrix boundaries
      */
-    Q_REQUIRED_RESULT static QPair<QDate, QDate> matrixLimits(QDate month);
+    [[nodiscard]] static QPair<QDate, QDate> matrixLimits(QDate month);
 
     /**
       Associate a calendar with this day matrix. If there is a calendar, the
       day matrix will accept drops and days with events will be highlighted.
     */
-    void setCalendar(const Akonadi::ETMCalendar::Ptr &);
+    void addCalendar(const Akonadi::CollectionCalendar::Ptr &calendar);
+    void removeCalendar(const Akonadi::CollectionCalendar::Ptr &calendar);
 
     /** updates the day matrix to start with the given date. Does all the
      *  necessary checks for holidays or events on a day and stores them
@@ -127,7 +128,7 @@ public:
     /** Is today visible in the view? Keep this in sync with
      * the values today (below) can take.
      */
-    Q_REQUIRED_RESULT bool isTodayVisible() const
+    [[nodiscard]] bool isTodayVisible() const
     {
         return mToday >= 0;
     }
@@ -139,12 +140,12 @@ public:
      * in the array of visible dates and going from
      * top left (0) to bottom right (41).
      */
-    Q_REQUIRED_RESULT bool isBeginningOfMonth() const
+    [[nodiscard]] bool isBeginningOfMonth() const
     {
         return mToday <= 8;
     }
 
-    Q_REQUIRED_RESULT bool isEndOfMonth() const
+    [[nodiscard]] bool isEndOfMonth() const
     {
         return mToday >= 27;
     }
@@ -264,7 +265,7 @@ private:
     static const int NUMDAYS;
 
     /** calendar instance to be queried for holidays, events, ... */
-    Akonadi::ETMCalendar::Ptr mCalendar;
+    QList<Akonadi::CollectionCalendar::Ptr> mCalendars;
 
     /** starting date of the matrix */
     QDate mStartDate;
