@@ -14,12 +14,12 @@
 #include "prefs/koprefs.h"
 
 #include <CalendarSupport/ArchiveDialog>
-#include <CalendarSupport/Utils>
 #include <PimCommon/PimUtil>
 
 #include <IncidenceEditor/IncidenceDialog>
 #include <IncidenceEditor/IncidenceDialogFactory>
 
+#include <Akonadi/CalendarUtils>
 #include <Akonadi/Item>
 #include <Akonadi/TagManagementDialog>
 
@@ -68,7 +68,7 @@ void KODialogManager::showOptionsDialog()
     if (!mOptionsDialog) {
         mOptionsDialog = new KCMultiDialog(mMainView);
         connect(mOptionsDialog, qOverload<>(&KCMultiDialog::configCommitted), mMainView, &CalendarView::updateConfig);
-        const QVector<KPluginMetaData> availablePlugins = KPluginMetaData::findPlugins(QStringLiteral("pim/kcms/korganizer"));
+        const QList<KPluginMetaData> availablePlugins = KPluginMetaData::findPlugins(QStringLiteral("pim6/kcms/korganizer"));
         for (const KPluginMetaData &metaData : availablePlugins) {
             mOptionsDialog->addModule(metaData);
         }
@@ -88,14 +88,14 @@ void KODialogManager::showSearchDialog()
 {
     if (!mSearchDialog) {
         mSearchDialog = new SearchDialog(mMainView);
-        connect(mMainView->calendar().data(), &Akonadi::ETMCalendar::calendarChanged,
-                mSearchDialog, &SearchDialog::updateView);
-        connect(mSearchDialog, &SearchDialog::showIncidenceSignal,
-                mMainView, qOverload<const Akonadi::Item &>(&CalendarView::showIncidence));
-        connect(mSearchDialog, &SearchDialog::editIncidenceSignal,
-                mMainView, [=](const Akonadi::Item & i){mMainView->editIncidence(i);});
-        connect(mSearchDialog, &SearchDialog::deleteIncidenceSignal,
-                mMainView, [=](const Akonadi::Item & i){mMainView->deleteIncidence(i, false);});
+        connect(mMainView->calendar().data(), &Akonadi::ETMCalendar::calendarChanged, mSearchDialog, &SearchDialog::updateView);
+        connect(mSearchDialog, &SearchDialog::showIncidenceSignal, mMainView, qOverload<const Akonadi::Item &>(&CalendarView::showIncidence));
+        connect(mSearchDialog, &SearchDialog::editIncidenceSignal, mMainView, [=](const Akonadi::Item &i) {
+            mMainView->editIncidence(i);
+        });
+        connect(mSearchDialog, &SearchDialog::deleteIncidenceSignal, mMainView, [=](const Akonadi::Item &i) {
+            mMainView->deleteIncidence(i, false);
+        });
     }
     // make sure the widget is on top again
     mSearchDialog->show();
@@ -130,7 +130,7 @@ void KODialogManager::showFilterEditDialog(QList<KCalendarCore::CalFilter *> *fi
 
 IncidenceEditorNG::IncidenceDialog *KODialogManager::createDialog(const Akonadi::Item &item)
 {
-    const KCalendarCore::Incidence::Ptr incidence = CalendarSupport::incidence(item);
+    const KCalendarCore::Incidence::Ptr incidence = Akonadi::CalendarUtils::incidence(item);
     if (!incidence) {
         return nullptr;
     }
@@ -175,3 +175,5 @@ void KODialogManager::slotHelp()
 {
     PimCommon::Util::invokeHelp(QStringLiteral("korganizer/categories-view.html"));
 }
+
+#include "moc_kodialogmanager.cpp"
