@@ -17,19 +17,10 @@
 
 K_PLUGIN_CLASS_WITH_JSON(KCMTodoSummary, "kcmtodosummary.json")
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-KCMTodoSummary::KCMTodoSummary(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-#else
-KCMTodoSummary::KCMTodoSummary(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
-#endif
+KCMTodoSummary::KCMTodoSummary(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    setupUi(this);
-#else
     setupUi(widget());
-#endif
 
     customDaysChanged(7);
 
@@ -48,11 +39,7 @@ KCMTodoSummary::KCMTodoSummary(QObject *parent, const KPluginMetaData &data, con
 
     connect(mShowMineOnly, &QCheckBox::stateChanged, this, &KCMTodoSummary::modified);
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    KAcceleratorManager::manage(this);
-#else
     KAcceleratorManager::manage(widget());
-#endif
 
     load();
 }
@@ -61,11 +48,7 @@ KCMTodoSummary::~KCMTodoSummary() = default;
 
 void KCMTodoSummary::modified()
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(true);
-#else
     markAsChanged();
-#endif
 }
 
 void KCMTodoSummary::customDaysChanged(int value)
@@ -78,7 +61,7 @@ void KCMTodoSummary::load()
     // Note: match default entry values with those in defaults() and
     // TodoSummaryWidget::updateView().
     KConfig config(QStringLiteral("kcmtodosummaryrc"));
-    KConfigGroup group = config.group("Days");
+    KConfigGroup group = config.group(QStringLiteral("Days"));
 
     int days = group.readEntry("DaysToShow", 7);
     if (days == 1) {
@@ -91,27 +74,23 @@ void KCMTodoSummary::load()
         mCustomDays->setEnabled(true);
     }
 
-    group = config.group("Hide");
+    group = config.group(QStringLiteral("Hide"));
     mHideInProgressBox->setChecked(group.readEntry("InProgress", false));
     mHideOverdueBox->setChecked(group.readEntry("Overdue", false));
     mHideCompletedBox->setChecked(group.readEntry("Completed", true));
     mHideOpenEndedBox->setChecked(group.readEntry("OpenEnded", true));
     mHideUnstartedBox->setChecked(group.readEntry("NotStarted", false));
 
-    group = config.group("Groupware");
+    group = config.group(QStringLiteral("Groupware"));
     mShowMineOnly->setChecked(group.readEntry("ShowMineOnly", false));
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(false);
-#else
     setNeedsSave(false);
-#endif
 }
 
 void KCMTodoSummary::save()
 {
     KConfig config(QStringLiteral("kcmtodosummaryrc"));
-    KConfigGroup group = config.group("Days");
+    KConfigGroup group = config.group(QStringLiteral("Days"));
 
     int days;
     if (mDateTodayButton->isChecked()) {
@@ -123,22 +102,18 @@ void KCMTodoSummary::save()
     }
     group.writeEntry("DaysToShow", days);
 
-    group = config.group("Hide");
+    group = config.group(QStringLiteral("Hide"));
     group.writeEntry("InProgress", mHideInProgressBox->isChecked());
     group.writeEntry("Overdue", mHideOverdueBox->isChecked());
     group.writeEntry("Completed", mHideCompletedBox->isChecked());
     group.writeEntry("OpenEnded", mHideOpenEndedBox->isChecked());
     group.writeEntry("NotStarted", mHideUnstartedBox->isChecked());
 
-    group = config.group("Groupware");
+    group = config.group(QStringLiteral("Groupware"));
     group.writeEntry("ShowMineOnly", mShowMineOnly->isChecked());
 
     config.sync();
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(false);
-#else
     setNeedsSave(false);
-#endif
 }
 
 void KCMTodoSummary::defaults()
@@ -155,11 +130,9 @@ void KCMTodoSummary::defaults()
 
     mShowMineOnly->setChecked(false);
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    Q_EMIT changed(true);
-#else
     markAsChanged();
-#endif
 }
 
 #include "kcmtodosummary.moc"
+
+#include "moc_kcmtodosummary.cpp"
