@@ -8,7 +8,6 @@
 */
 
 #pragma once
-#include "kcmutils_version.h"
 #include "ui_todosummaryconfig_base.h"
 #include <KCModule>
 
@@ -17,11 +16,7 @@ class KCMTodoSummary : public KCModule, public Ui::TodoSummaryConfig_Base
     Q_OBJECT
 
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KCMTodoSummary(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
-#else
-    explicit KCMTodoSummary(QObject *parent, const KPluginMetaData &data, const QVariantList &args = QVariantList());
-#endif
+    explicit KCMTodoSummary(QObject *parent, const KPluginMetaData &data);
     ~KCMTodoSummary() override;
 
     void load() override;
