@@ -8,7 +8,6 @@
 */
 
 #pragma once
-#include "kcmutils_version.h"
 #include "ui_sdsummaryconfig_base.h"
 #include <KCModule>
 
@@ -17,11 +16,7 @@ class KCMSDSummary : public KCModule, public Ui::SDSummaryConfig_Base
     Q_OBJECT
 
 public:
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    explicit KCMSDSummary(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
-#else
-    explicit KCMSDSummary(QObject *parent, const KPluginMetaData &data, const QVariantList &args = QVariantList());
-#endif
+    explicit KCMSDSummary(QObject *parent, const KPluginMetaData &data);
 
     void load() override;
     void save() override;
