@@ -34,13 +34,8 @@
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 
-#ifdef USE_KUSERFEEDBACK_QT6
 #include <KUserFeedbackQt6/NotificationPopup>
 #include <KUserFeedbackQt6/Provider>
-#else
-#include <KUserFeedback/NotificationPopup>
-#include <KUserFeedback/Provider>
-#endif
 #endif
 
 KOrganizer::KOrganizer()
@@ -291,3 +286,5 @@ void KOrganizer::setTitle()
 
     setCaption(title, false);
 }
+
+#include "moc_korganizer.cpp"
