@@ -18,20 +18,11 @@
 
 K_PLUGIN_CLASS_WITH_JSON(KOPrefsDialogGroupwareScheduling, "korganizer_configfreebusy.json")
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-KOPrefsDialogGroupwareScheduling::KOPrefsDialogGroupwareScheduling(QWidget *parent, const QVariantList &args)
-    : Korganizer::KPrefsModule(CalendarSupport::KCalPrefs::instance(), parent, args)
-#else
-KOPrefsDialogGroupwareScheduling::KOPrefsDialogGroupwareScheduling(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : Korganizer::KPrefsModule(CalendarSupport::KCalPrefs::instance(), parent, data, args)
-#endif
+KOPrefsDialogGroupwareScheduling::KOPrefsDialogGroupwareScheduling(QObject *parent, const KPluginMetaData &data)
+    : Korganizer::KPrefsModule(CalendarSupport::KCalPrefs::instance(), parent, data)
     , mGroupwarePage(new Ui::KOGroupwarePrefsPage())
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto widget = new QWidget(this);
-#else
     auto widget = new QWidget(this->widget());
-#endif
     widget->setObjectName(QStringLiteral("KOGrouparePrefsPage"));
 
     mGroupwarePage->setupUi(widget);
@@ -53,11 +44,7 @@ KOPrefsDialogGroupwareScheduling::KOPrefsDialogGroupwareScheduling(QObject *pare
     connect(mGroupwarePage->fullDomainRetrieval, &QCheckBox::toggled, this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
     connect(mGroupwarePage->publishEnable, &QCheckBox::toggled, this, &KOPrefsDialogGroupwareScheduling::slotWidChanged);
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    (new QVBoxLayout(this))->addWidget(widget);
-#else
     (new QVBoxLayout(this->widget()))->addWidget(widget);
-#endif
 
     load();
 }
@@ -111,3 +98,5 @@ void KOPrefsDialogGroupwareScheduling::usrWriteConfig()
 }
 
 #include "koprefsdialoggroupwarescheduling.moc"
+
+#include "moc_koprefsdialoggroupwarescheduling.cpp"
