@@ -15,29 +15,15 @@
 #ifdef WITH_KUSERFEEDBACK
 #include "userfeedback/userfeedbackmanager.h"
 
-#ifdef USE_KUSERFEEDBACK_QT6
 #include <KUserFeedbackQt6/FeedbackConfigWidget>
-#else
-#include <KUserFeedback/FeedbackConfigWidget>
-#endif
 
 K_PLUGIN_CLASS_WITH_JSON(KOPrefsUserFeedBack, "korganizer_userfeedback.json")
 
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-KOPrefsUserFeedBack::KOPrefsUserFeedBack(QWidget *parent, const QVariantList &args)
-    : KCModule(parent, args)
-    , mUserFeedbackWidget(new KUserFeedback::FeedbackConfigWidget(this))
-#else
-KOPrefsUserFeedBack::KOPrefsUserFeedBack(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
-    : KCModule(parent, data, args)
+KOPrefsUserFeedBack::KOPrefsUserFeedBack(QObject *parent, const KPluginMetaData &data)
+    : KCModule(parent, data)
     , mUserFeedbackWidget(new KUserFeedback::FeedbackConfigWidget(widget()))
-#endif
 {
-#if KCMUTILS_VERSION < QT_VERSION_CHECK(5, 240, 0)
-    auto layout = new QVBoxLayout(this);
-#else
     auto layout = new QVBoxLayout(widget());
-#endif
     layout->setContentsMargins({});
 
     connect(mUserFeedbackWidget, &KUserFeedback::FeedbackConfigWidget::configurationChanged, this, &KOPrefsUserFeedBack::markAsChanged);
