@@ -6,7 +6,6 @@
 
 #include "korganizeruserfeedbackprovider.h"
 
-#ifdef USE_KUSERFEEDBACK_QT6
 #include <KUserFeedbackQt6/ApplicationVersionSource>
 #include <KUserFeedbackQt6/LocaleInfoSource>
 #include <KUserFeedbackQt6/PlatformInfoSource>
@@ -14,15 +13,6 @@
 #include <KUserFeedbackQt6/ScreenInfoSource>
 #include <KUserFeedbackQt6/StartCountSource>
 #include <KUserFeedbackQt6/UsageTimeSource>
-#else
-#include <KUserFeedback/ApplicationVersionSource>
-#include <KUserFeedback/LocaleInfoSource>
-#include <KUserFeedback/PlatformInfoSource>
-#include <KUserFeedback/QtVersionSource>
-#include <KUserFeedback/ScreenInfoSource>
-#include <KUserFeedback/StartCountSource>
-#include <KUserFeedback/UsageTimeSource>
-#endif
 
 KOrganizerUserFeedbackProvider::KOrganizerUserFeedbackProvider(QObject *parent)
     : KUserFeedback::Provider(parent)
@@ -45,3 +35,5 @@ KOrganizerUserFeedbackProvider::KOrganizerUserFeedbackProvider(QObject *parent)
 }
 
 KOrganizerUserFeedbackProvider::~KOrganizerUserFeedbackProvider() = default;
+
+#include "moc_korganizeruserfeedbackprovider.cpp"
