@@ -22,7 +22,7 @@ public:
     ~KItemIconCheckCombo() override;
 
     void setCheckedIcons(const QSet<EventViews::EventView::ItemIcon> &icons);
-    Q_REQUIRED_RESULT QSet<EventViews::EventView::ItemIcon> checkedIcons() const;
+    [[nodiscard]] QSet<EventViews::EventView::ItemIcon> checkedIcons() const;
 
 private:
     const KItemIconCheckCombo::ViewType mViewType;
